"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SharedStateProvider = SharedStateProvider;
exports.ShareContext = void 0;

var _client = _interopRequireDefault(require("sharedb/lib/client"));

var _react = _interopRequireWildcard(require("react"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function SharedStateProvider(props) {
  const connection = props.connection || null;
  const websocket = props.websocket || null;
  const children = props.children;

  if (process.env.NODE_ENV !== 'production') {
    // eslint-disable-next-line react-hooks/rules-of-hooks
    const first_conn_ref = (0, _react.useRef)(connection);

    if (!first_conn_ref.current) {
      if (connection) {
        // eslint-disable-next-line no-console
        console.warn('<SharedStateProvider>: received `connection` but was not present on first render');
      }
    } else {
      if (!connection) {
        // eslint-disable-next-line no-console
        console.warn('<SharedStateProvider>: received `connection` on first render but was not present');
      } else if (first_conn_ref.current !== connection) {
        // eslint-disable-next-line no-console
        console.warn('<SharedStateProvider>: received different `connection` than first render');
      }
    }
  }

  const [managed_conn, setConn] = (0, _react.useState)(null);
  (0, _react.useEffect)(() => {
    if (!connection) {
      // create a managed connection and bind it to a dummy websocket
      const managed_conn = new _client.default.Connection({
        close: () => {},
        readyState: 3
      });
      setConn(managed_conn);
      return () => {
        // TODO: figure out how to properly clean up the connection
        // TODO: maybe bypass delayed calls to destroy docs?
        managed_conn.close();
        setConn(null);
      };
    }
  }, [connection]);
  (0, _react.useEffect)(() => {
    if (managed_conn && websocket) {
      managed_conn.bindToSocket(websocket);
    }
  }, [managed_conn, websocket]);

  if (!connection && !managed_conn) {
    // can't render the provider and children until we have a connection
    return null;
  }

  return _react.default.createElement(ShareContext.Provider, {
    value: connection || managed_conn
  }, children);
}

const ShareContext = (0, _react.createContext)();
exports.ShareContext = ShareContext;